@@ -21,7 +21,7 @@ if (slow) {
         tsplit <- transform(tsplit, dt=t-tstart)
         fit <- gam(e~s(log(t))+offset(log(dt)), data=tsplit, family=poisson)
         fit <- markov_msm(list(fit), trans=matrix(c(NA,1,NA,NA),2,2,TRUE), newdata=data.frame(dt=1),
-                          t=c(0,2),tmvar="t")
+                          t=c(0,2),tmvar="t", spline.interpolation=FALSE)
         expect_eps(as.data.frame(fit)$P[4], 0.9786583, 1e-5)
     })
 }
@@ -33,8 +33,11 @@ test_that("glm", {
     tsplit <- survival::survSplit(Surv(t,e)~1, data=d, cut=seq(0,6,length=100))
     tsplit <- transform(tsplit, dt=t-tstart)
     fit <- glm(e~ns(log(t),df=3)+offset(log(dt)), data=tsplit, family=poisson)
-    fit <- markov_msm(list(fit), trans=matrix(c(NA,1,NA,NA),2,2,TRUE), newdata=data.frame(dt=1),
-                      t=c(0,2),tmvar="t")
-    expect_eps(as.data.frame(fit)$P[4], 0.977278, 1e-5)
+    fit2 <- markov_msm(list(fit), trans=matrix(c(NA,1,NA,NA),2,2,TRUE), newdata=data.frame(dt=1),
+                      t=c(0,2),tmvar="t", spline.interpolation=TRUE)
+    expect_eps(as.data.frame(fit2)$P[4], 0.977278, 1e-5)
+    fit2 <- markov_msm(list(fit), trans=matrix(c(NA,1,NA,NA),2,2,TRUE), newdata=data.frame(dt=1),
+                      t=c(0,2),tmvar="t", spline.interpolation=FALSE)
+    expect_eps(as.data.frame(fit2)$P[4], 0.977278, 1e-5)
 })
 
